# -*- coding: utf-8 -*-

# LICENSE

from OFS.SimpleItem import SimpleItem
from App.class_init import InitializeClass
from AccessControl import ClassSecurityInfo
from DocumentTemplate.DT_Util import html_quote
from AccessControl import Unauthorized, getSecurityManager, SpecialUsers
from ZODB.POSException import ConflictError
from AccessControl.SecurityManagement import newSecurityManager
from DateTime.DateTime import DateTime

# CMF imports
from Products.CMFCore.utils import UniqueObject, getToolByName
from Products.CMFCore.ActionProviderBase import ActionProviderBase
from Products.CMFCore.ActionInformation import ActionInformation
from Products.CMFCore.Expression import Expression

# Product imports
from GenClass.config import *

from zLOG import LOG, INFO

class GenClassTool(UniqueObject, SimpleItem, ActionProviderBase):
    
    id = TOOL_ID
    meta_type = TOOL_META_TYPE
    title = TOOL_TITLE
    
    security = ClassSecurityInfo()
    security.declareObjectProtected('View')
    
    security.declareProtected('View', 'getDA')
    def getDA(self, ):
        """Returns the eXistDA used for the tool"""
        pprops = getToolByName(self, 'portal_properties')
        DA_id = pprops['genclass_properties'].getProperty('EXIST_DA')
        portal = getToolByName(self, "portal_url").getPortalObject()
        try:
            DA = getattr(portal, DA_id, None)
            name = DA.getDA()
        except:
            raise "eXist DA %s not found." % DA_id
        return DA
        
        
    def getLng(self, lng_code=''):
        """Returns the languages available for the software"""
        gc_props = getToolByName(self, 'portal_properties')['genclass_properties']

        liste_lng = []

        if lng_code.strip() == '':
            for n in gc_props.getProperty('LNG', []):
                code, value = n.strip().split('|')
                liste_lng.append({'code':code, 'value':value})
            return liste_lng
            
        for n in gc_props.getProperty('LNG', []):
            code, value = n.strip().split('|')
            if code == lng_code:
                return value
        return ''
        
    def getNSandXMLNS(self, ns=''):
        """Returns NS and XMLNS used by the software"""
        gc_props = getToolByName(self, 'portal_properties')['genclass_properties']

        liste_ns = []
        if ns == '*':
            for n in gc_props.getProperty('NS', []):
                thisns, xmlns = n.strip().split('|')
                liste_ns.append(thisns)
            return liste_ns
            
        for l in gc_props.getProperty('NS', []):
            thisns, xmlns = l.strip().split('|')
            if ns == thisns:
                return (ns, xmlns, )
        return ()

    
    
InitializeClass(GenClassTool)
